@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2006 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rd.h,v 1.188.2.1 2008-11-24 18:25:21 fredg Exp $
+//      $Id: rd.h,v 1.188.2.2 2009/05/21 17:32:17 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -226,6 +226,11 @@
 #define RD_SERVICE_NAME "Production"
 #define RD_SERVICE_DESCRIPTION "Default Audio Service"
 
+/*
+ * Default Maximum POST Length (bytes)
+ */
+#define RD_DEFAULT_MAX_POST_LENGTH 10000000
+
 /*
  * Pause Time for Starting Daemons (secs)
  */
