@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdimport_audio.h,v 1.7 2007/05/10 04:38:47 daservis Exp $
+//      $Id: rdimport_audio.h,v 1.8 2007/09/14 14:06:24 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -39,12 +39,7 @@
 #include <qbuttongroup.h>
 #include <qradiobutton.h>
 
-#include <rtransportbutton.h>
-#include <rwavedata.h>
-#include <rcdplayer.h>
-#include <rcddbrecord.h>
-#include <rcddblookup.h>
-
+#include <rdwavedata.h>
 #include <rdconfig.h>
 #include <rdsettings.h>
 #include <rdexport_settings_dialog.h>
@@ -67,7 +62,7 @@ class RDImportAudio : public QDialog
  Q_OBJECT
  public:
  RDImportAudio(QString cutname,QString *path,RDSettings *settings,
-	       bool *import_metadata,RWaveData *wavedata,
+	       bool *import_metadata,RDWaveData *wavedata,
 	       RDCut *clipboard,RDStation *station,bool *running,
 	       RDConfig *config,QWidget *parent=0,const char *name=0);
   ~RDImportAudio();
@@ -145,7 +140,7 @@ class RDImportAudio : public QDialog
   unsigned import_finished_length;
   bool *import_import_metadata;
   RDSettings *import_settings;
-  RWaveData *import_wavedata;
+  RDWaveData *import_wavedata;
   QString import_tempwav_name;
   QString import_tempdat_name;
 };
