@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdmacro_event.cpp,v 1.16 2007/02/14 21:48:41 fredg Exp $
+//      $Id: rdmacro_event.cpp,v 1.17 2007/10/04 20:53:28 dmills Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -19,7 +19,7 @@
 //   License along with this program; if not, write to the Free Software
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
-
+#include <rddb.h>
 #include <rdmacro_event.h>
 #include <rdstation.h>
 
@@ -132,7 +132,7 @@ bool RDMacroEvent::load(unsigned cartnum)
 {
   QString sql=QString().
     sprintf("select MACROS from CART where (NUMBER=%d)&&(TYPE=2)",cartnum);
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   if(!q->first()) {
     delete q;
     clear();
@@ -212,7 +212,7 @@ void RDMacroEvent::exec()
 void RDMacroEvent::exec(int line)
 {
   QString sql;
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString stationname;
 
   if(event_ripc==NULL) {
@@ -236,7 +236,7 @@ void RDMacroEvent::exec(int line)
                              where (STATION_NAME=\"%s\")&&(NAME=\"%s\")",
 			    (const char *)event_ripc->station(),
 			    (const char *)stationname);
-	q=new QSqlQuery(sql);
+	q=new RDSqlQuery(sql);
 	if(q->first()) {
 	  stationname=q->value(0).toString();
 	}
