@@ -2,9 +2,9 @@
 //
 // Abstract a Rivendell Switcher Matrix
 //
-//   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
+//   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdmatrix.cpp,v 1.19 2007/02/14 21:48:41 fredg Exp $
+//      $Id: rdmatrix.cpp,v 1.24.2.1 2009/02/10 16:19:32 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -20,7 +20,9 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
+#include <rddb.h>
 #include <rdmatrix.h>
+#include <rdescape_string.h>
 
 
 RDMatrix::RDMatrix(const QString &station,int matrix)
@@ -46,7 +48,7 @@ bool RDMatrix::exists() const
 {
   QString sql=QString().sprintf("select TYPE from MATRICES where MATRIX=%d",
 				mx_number);
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   bool result=q->first();
   delete q;
   return result;
@@ -65,6 +67,18 @@ void RDMatrix::setType(RDMatrix::Type type) const
 }
 
 
+int RDMatrix::layer() const
+{
+  return GetRow("LAYER").toInt();
+}
+
+
+void RDMatrix::setLayer(int layer)
+{
+  SetRow("LAYER",layer);
+}
+
+
 QString RDMatrix::typeString() const
 {
   switch(type()) {
@@ -148,6 +162,14 @@ QString RDMatrix::typeString() const
 	return QString("BroadcastTools SS4.2");
 	break;
 
+      case RDMatrix::LiveWire:
+	return QString("Axia LiveWire");
+	break;
+
+      case RDMatrix::Quartz1:
+	return QString("Quartz Type 1");
+	break;
+
       default:
 	return QString("Unknown Type");
 	break;
@@ -168,29 +190,61 @@ void RDMatrix::setName(const QString &name) const
 }
 
 
-RDMatrix::PortType RDMatrix::portType() const
+RDMatrix::PortType RDMatrix::portType(RDMatrix::Role role) const
 {
-  return (RDMatrix::PortType)GetRow("PORT_TYPE").toInt();
+  switch(role) {
+    case RDMatrix::Primary:
+      return (RDMatrix::PortType)GetRow("PORT_TYPE").toInt();
+
+    case RDMatrix::Backup:
+      return (RDMatrix::PortType)GetRow("PORT_TYPE_2").toInt();
+  }
+  return RDMatrix::TtyPort;
 }
 
 
-void RDMatrix::setPortType(PortType type) const
+void RDMatrix::setPortType(RDMatrix::Role role,PortType type) const
 {
-  SetRow("PORT_TYPE",(int)type);
+  switch(role) {
+    case RDMatrix::Primary:
+      SetRow("PORT_TYPE",(int)type);
+      break;
+
+    case RDMatrix::Backup:
+      SetRow("PORT_TYPE_2",(int)type);
+      break;
+  }
 }
 
 
-QHostAddress RDMatrix::ipAddress() const
+QHostAddress RDMatrix::ipAddress(RDMatrix::Role role) const
 {
   QHostAddress addr;
-  addr.setAddress(GetRow("IP_ADDRESS").toString());
+  switch(role) {
+    case RDMatrix::Primary:
+      addr.setAddress(GetRow("IP_ADDRESS").toString());
+      break;
+
+    case RDMatrix::Backup:
+      addr.setAddress(GetRow("IP_ADDRESS_2").toString());
+      break;
+  }
+
   return addr;
 }
 
 
-void RDMatrix::setIpAddress(QHostAddress addr) const
+void RDMatrix::setIpAddress(RDMatrix::Role role,QHostAddress addr) const
 {
-  SetRow("IP_ADDRESS",addr.toString());
+  switch(role) {
+    case RDMatrix::Primary:
+      SetRow("IP_ADDRESS",addr.toString());
+      break;
+
+    case RDMatrix::Backup:
+      SetRow("IP_ADDRESS_2",addr.toString());
+      break;
+  }
 }
 
 
@@ -206,51 +260,158 @@ void RDMatrix::setCard(int card) const
 }
 
 
-int RDMatrix::ipPort() const
+int RDMatrix::ipPort(RDMatrix::Role role) const
 {
-  return GetRow("IP_PORT").toInt();
+  switch(role) {
+    case RDMatrix::Primary:
+      return GetRow("IP_PORT").toInt();
+
+    case RDMatrix::Backup:
+      return GetRow("IP_PORT_2").toInt();
+  }
+  return 0;
 }
 
 
-void RDMatrix::setIpPort(int port) const
+void RDMatrix::setIpPort(RDMatrix::Role role,int port) const
 {
-  SetRow("IP_PORT",port);
+  switch(role) {
+    case RDMatrix::Primary:
+      SetRow("IP_PORT",port);
+
+    case RDMatrix::Backup:
+      SetRow("IP_PORT_2",port);
+  }
 }
 
 
-QString RDMatrix::username() const
+QString RDMatrix::username(RDMatrix::Role role) const
 {
-  return GetRow("USERNAME").toString();
+  switch(role) {
+    case RDMatrix::Primary:
+      return GetRow("USERNAME").toString();
+
+    case RDMatrix::Backup:
+      return GetRow("USERNAME_2").toString();
+  }
+  return QString();
 }
 
 
-void RDMatrix::setUsername(const QString &name) const
+void RDMatrix::setUsername(RDMatrix::Role role,const QString &name) const
 {
-  SetRow("USERNAME",name);
+  switch(role) {
+    case RDMatrix::Primary:
+      SetRow("USERNAME",name);
+
+    case RDMatrix::Backup:
+      SetRow("USERNAME_2",name);
+  }
 }
 
 
-QString RDMatrix::password() const
+QString RDMatrix::password(RDMatrix::Role role) const
 {
-  return GetRow("PASSWORD").toString();
+  switch(role) {
+    case RDMatrix::Primary:
+      return GetRow("PASSWORD").toString();
+
+    case RDMatrix::Backup:
+      return GetRow("PASSWORD_2").toString();
+  }
+  return QString();
 }
 
 
-void RDMatrix::setPassword(const QString &passwd) const
+void RDMatrix::setPassword(RDMatrix::Role role,const QString &passwd) const
 {
-  SetRow("PASSWORD",passwd);
+  switch(role) {
+    case RDMatrix::Primary:
+      SetRow("PASSWORD",passwd);
+
+    case RDMatrix::Backup:
+      SetRow("PASSWORD_2",passwd);
+
+  }
 }
 
 
-int RDMatrix::port() const
+unsigned RDMatrix::startCart(RDMatrix::Role role) const
 {
-  return GetRow("PORT").toInt();
+  switch(role) {
+    case RDMatrix::Primary:
+      return GetRow("START_CART").toUInt();
+
+    case RDMatrix::Backup:
+      return GetRow("START_CART_2").toUInt();
+  }
+  return 0;
 }
 
 
-void RDMatrix::setPort(int port) const
+void RDMatrix::setStartCart(RDMatrix::Role role,unsigned cartnum) const
 {
-  SetRow("PORT",port);
+  switch(role) {
+    case RDMatrix::Primary:
+      SetRow("START_CART",cartnum);
+
+    case RDMatrix::Backup:
+      SetRow("START_CART_2",cartnum);
+
+  }
+}
+
+
+unsigned RDMatrix::stopCart(RDMatrix::Role role) const
+{
+  switch(role) {
+    case RDMatrix::Primary:
+      return GetRow("STOP_CART").toUInt();
+
+    case RDMatrix::Backup:
+      return GetRow("STOP_CART_2").toUInt();
+  }
+  return 0;
+}
+
+
+void RDMatrix::setStopCart(RDMatrix::Role role,unsigned cartnum) const
+{
+  switch(role) {
+    case RDMatrix::Primary:
+      SetRow("STOP_CART",cartnum);
+
+    case RDMatrix::Backup:
+      SetRow("STOP_CART_2",cartnum);
+
+  }
+}
+
+
+int RDMatrix::port(RDMatrix::Role role) const
+{
+  switch(role) {
+    case RDMatrix::Primary:
+      return GetRow("PORT").toInt();
+
+    case RDMatrix::Backup:
+      return GetRow("PORT_2").toInt();
+  }
+  return -1;
+}
+
+
+void RDMatrix::setPort(RDMatrix::Role role,int port) const
+{
+  switch(role) {
+    case RDMatrix::Primary:
+      SetRow("PORT",port);
+      break;
+
+    case RDMatrix::Backup:
+      SetRow("PORT_2",port);
+      break;
+  }
 }
 
 
@@ -280,7 +441,7 @@ RDMatrix::Mode RDMatrix::inputMode(int input) const
 				(const char *)mx_station,
 				mx_number,
 				input);
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   if(!q->first()) {
     delete q;
     return RDMatrix::Stereo;
@@ -378,7 +539,7 @@ QString RDMatrix::GetEndpointName(int pointnum,const QString &table) const
 				(const char *)mx_station,
 				mx_number,
 				pointnum);
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   if(!q->first()) {
     delete q;
     return QString("NULL");
@@ -394,10 +555,10 @@ QVariant RDMatrix::GetRow(const QString &param) const
   QVariant var;
   QString sql=QString().sprintf("select %s from MATRICES where \
                                 STATION_NAME=\"%s\" && MATRIX=%d",
-				(const char *)param,
+				(const char *)RDEscapeString(param),
 				(const char *)mx_station,
                                 mx_number);
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   if(q->first()) {
     var=q->value(0);
   }
@@ -408,31 +569,47 @@ QVariant RDMatrix::GetRow(const QString &param) const
 
 void RDMatrix::SetRow(const QString &param,const QString &value) const
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   sql=QString().sprintf("UPDATE MATRICES SET %s=\"%s\" \
                          WHERE STATION_NAME=\"%s\" && MATRIX=%d",
-			(const char *)param,
-			(const char *)value,
+			(const char *)RDEscapeString(param),
+			(const char *)RDEscapeString(value),
 			(const char *)mx_station,
 			mx_number);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
   delete q;
 }
 
 
 void RDMatrix::SetRow(const QString &param,int value) const
 {
-  QSqlQuery *q;
+  RDSqlQuery *q;
   QString sql;
 
   sql=QString().sprintf("UPDATE MATRICES SET %s=%d \
                          WHERE STATION_NAME=\"%s\" && MATRIX=%d",
-			(const char *)param,
+			(const char *)RDEscapeString(param),
 			value,
 			(const char *)mx_station,
 			mx_number);
-  q=new QSqlQuery(sql);
+  q=new RDSqlQuery(sql);
+  delete q;
+}
+
+
+void RDMatrix::SetRow(const QString &param,unsigned value) const
+{
+  RDSqlQuery *q;
+  QString sql;
+
+  sql=QString().sprintf("UPDATE MATRICES SET %s=%u \
+                         WHERE STATION_NAME=\"%s\" && MATRIX=%d",
+			(const char *)RDEscapeString(param),
+			value,
+			(const char *)mx_station,
+			mx_number);
+  q=new RDSqlQuery(sql);
   delete q;
 }
