@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdsvc.cpp,v 1.66.2.3 2008/12/11 19:55:06 fredg Exp $
+//      $Id: rdsvc.cpp,v 1.66.2.5 2009/02/12 14:21:26 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -663,7 +663,6 @@ bool RDSvc::generateLog(const QDate &date,const QString &logname,
       sql+=(",PURGE_DATE=\""+purge_date+"\"");
     }
     sql+=(" where NAME=\""+RDEscapeString(logname)+"\"");
-    printf("SQL: %s\n",(const char *)sql);
 
     q=new RDSqlQuery(sql);
     delete q;
@@ -846,7 +845,7 @@ bool RDSvc::linkLog(RDSvc::ImportSource src,const QDate &date,
   //
   QString cartname;
   QString missing_report;
-  dest_event->validate(&missing_report);
+  dest_event->validate(&missing_report,date);
   bool event=false;
   QString link_report=tr("The following events were not placed:\n");
   sql=QString().sprintf("select `%s`.START_HOUR,`%s`.START_SECS,\
@@ -880,7 +879,7 @@ bool RDSvc::linkLog(RDSvc::ImportSource src,const QDate &date,
   //
   *report="";
   if(!autofill_errors.isEmpty()) {
-    *report+=tr("Autofill Errors\n");
+    *report+=tr("Event Fill Errors\n");
     *report+=autofill_errors;
     *report+="\n";
   }
