@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2004 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: autofill_carts.cpp,v 1.10 2007/09/14 14:06:26 fredg Exp $
+//      $Id: autofill_carts.cpp,v 1.14 2007/12/31 18:49:08 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -31,13 +31,14 @@
 #include <qmessagebox.h>
 #include <qcheckbox.h>
 #include <qbuttongroup.h>
-#include <qsqldatabase.h>
 
+#include <rddb.h>
 #include <rdconf.h>
 #include <rd.h>
 #include <rduser.h>
 #include <rdcart_dialog.h>
 
+#include <globals.h>
 #include <autofill_carts.h>
 
 
@@ -148,11 +149,7 @@ QSizePolicy AutofillCarts::sizePolicy() const
 void AutofillCarts::addData()
 {
   int cart=0;
-  RDCartDialog *cart_dialog=
-    new RDCartDialog(&cart,&svc_cart_filter,&svc_cart_group,
-		     RDCart::Audio,NULL,0,this,"cart_dialog");
-  if(cart_dialog->exec()<0) {
-    delete cart_dialog;
+  if(admin_cart_dialog->exec(&cart,RDCart::Audio,NULL,0)<0) {
     return;
   }
   RDCart *rdcart=new RDCart(cart);
@@ -164,7 +161,6 @@ void AutofillCarts::addData()
   svc_cart_list->setSelected(item,true);
   svc_cart_list->ensureItemVisible(item);
   delete rdcart;
-  delete cart_dialog;
 }
 
 
@@ -182,14 +178,14 @@ void AutofillCarts::okData()
 {
   QString sql=QString().sprintf("delete from AUTOFILLS where SERVICE=\"%s\"",
 				(const char *)svc_svc->name());
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   delete q;
   QListViewItem *item=svc_cart_list->firstChild();
   while(item!=NULL) {
     sql=QString().sprintf("insert into AUTOFILLS set SERVICE=\"%s\",\
                            CART_NUMBER=%u",(const char *)svc_svc->name(),
 			  item->text(0).toUInt());
-    q=new QSqlQuery(sql);
+    q=new RDSqlQuery(sql);
     delete q;
     item=item->nextSibling();
   }
@@ -214,7 +210,7 @@ void AutofillCarts::RefreshList()
                                  on AUTOFILLS.CART_NUMBER=CART.NUMBER\
                                  where SERVICE=\"%s\"",
 				(const char *)svc_svc->name());
-  QSqlQuery *q=new QSqlQuery(sql);
+  RDSqlQuery *q=new RDSqlQuery(sql);
   while(q->next()) {
     item=new QListViewItem(svc_cart_list);
     item->setText(0,QString().sprintf("%06u",q->value(0).toUInt()));
