@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2003 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: wall_clock.cpp,v 1.14 2007/09/14 14:06:48 fredg Exp $
+//      $Id: wall_clock.cpp,v 1.15 2007/10/01 10:40:45 fredg Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -38,7 +38,8 @@
 WallClock::WallClock(QWidget *parent,const char *name)
   :RDPushButton(parent,name)
 {
-  previous_time=QTime::currentTime().addMSecs(rdstation_conf->timeOffset());
+  time_offset=rdstation_conf->timeOffset();
+  previous_time=QTime::currentTime().addMSecs(time_offset);
   time_mode=RDAirPlayConf::TwentyFourHour;
   previous_time_mode = RDAirPlayConf::TwentyFourHour;
   show_date=true;
@@ -116,7 +117,7 @@ void WallClock::tickClock()
       setFlashingEnabled(!synced);
     }
   }
-  current_time=QTime::currentTime().addMSecs(rdstation_conf->timeOffset());
+  current_time=QTime::currentTime().addMSecs(time_offset);
   current_date=QDate::currentDate();
   if((current_time.second()==previous_time.second()) && (previous_time_mode == time_mode)) {
     return;
