@@ -4,7 +4,7 @@
 //
 //   (C) Copyright 2002-2007 Fred Gleason <fredg@paravelsystems.com>
 //
-//      $Id: rdcatchd.cpp,v 1.130.2.4 2009/03/31 11:21:01 cvs Exp $
+//      $Id: rdcatchd.cpp,v 1.130.2.6 2009/04/14 15:58:09 cvs Exp $
 //
 //   This program is free software; you can redistribute it and/or modify
 //   it under the terms of the GNU General Public License version 2 as
@@ -1496,10 +1496,14 @@ void MainObject::StartDownloadEvent(int event)
     if(protocol=="ftp") {
       catch_events[event].setTempName(BuildTempName(event,"download"));
       catch_events[event].setDeleteTempFile(true);
+      QString urlpath=url.path().right(url.path().length()-1);
+      urlpath.replace(" ","\\ ");
+      QString urlbase=RDGetBasePart(catch_events[event].tempName());
+      urlbase.replace(" ","\\ ");
       xload_cmd=QString().sprintf("lftp -e \"get -O %s %s -o %s;bye\"",
 		  (const char *)RDGetPathPart(catch_events[event].tempName()),
-		  (const char *)url.path().right(url.path().length()-1),
-		  (const char *)RDGetBasePart(catch_events[event].tempName()));
+				  (const char *)urlpath,
+				  (const char *)urlbase);
       if(!catch_events[event].urlUsername().isEmpty()) {
 	xload_cmd+=QString().sprintf(" -u \"%s",
 			  (const char *)catch_events[event].urlUsername());
@@ -1588,6 +1592,8 @@ void MainObject::StartUploadEvent(int event)
   RDUrl url(catch_events[event].resolvedUrl());
   QString protocol=url.protocol();
   QString temp_exportname;
+  QString urlpath;
+  QString dirpath;
 
   WriteExitCode(event,RDRecording::Uploading);
   catch_active_xloads.push_back(event);
@@ -1614,16 +1620,20 @@ void MainObject::StartUploadEvent(int event)
       if(dir=="/") {
 	dir="//";
       }
+      urlpath=RDGetBasePart(url.path());
+      urlpath.replace(" ","\\ ");
       if(dir.right(dir.length()-1)=="/") {
 	xload_cmd=QString().sprintf("lftp -e \"put %s -o %s;bye\"",
 			     (const char *)catch_events[event].tempName(),
-			     (const char *)RDGetBasePart(url.path()));
+			     (const char *)urlpath);
       }
       else {
+	dirpath=dir.right(dir.length()-1);
+	dirpath.replace(" ","\\ ");
 	xload_cmd=QString().sprintf("lftp -e \"put -O %s %s -o %s;bye\"",
-			     (const char *)dir.right(dir.length()-1),
+			     (const char *)dirpath,
 			     (const char *)catch_events[event].tempName(),
-			     (const char *)RDGetBasePart(url.path()));
+			     (const char *)urlpath);
       }
       if(!catch_events[event].urlUsername().isEmpty()) {
 	xload_cmd+=QString().sprintf(" -u \"%s",
@@ -1649,6 +1659,8 @@ void MainObject::StartUploadEvent(int event)
 			     catch_conf->errorRml());
 	return;
       }
+      urlpath=url.smbPath();
+      urlpath.replace(" ","\\ ");
       catch_events[event].setTempName(BuildTempName(event,"upload"));
       catch_events[event].setDeleteTempFile(true);
       QString path=RDGetPathPart(url.path());
@@ -1664,8 +1676,7 @@ void MainObject::StartUploadEvent(int event)
       }
       xload_cmd+=QString().
 	sprintf("-c \"put %s %s\"",(const char *)catch_events[event].
-		tempName(),
-		(const char *)url.smbPath());
+		tempName(),(const char *)urlpath);
     }
 
     //
@@ -2686,10 +2697,11 @@ bool MainObject::Import(int event)
     return false;
   }
   LogLine(RDConfig::LogInfo,QString().
-	  sprintf("started import of %s to cut %s, id=%d",
+	  sprintf("started import of %s to cut %s, id=%d, cmd=\"%s\"",
 		  (const char *)catch_events[event].tempName(),
 		  (const char *)catch_events[event].cutName(),
-		  catch_events[event].id()));
+		  catch_events[event].id(),
+		  (const char *)import_cmd));
   if(system(import_cmd)!=0) {
     WriteExitCode(event,RDRecording::ServerError);
     LogLine(RDConfig::LogWarning,QString().
